summaryrefslogtreecommitdiffstats
path: root/kapptemplate/kpartplugin/plugin_app.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kapptemplate/kpartplugin/plugin_app.cpp')
-rw-r--r--kapptemplate/kpartplugin/plugin_app.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kapptemplate/kpartplugin/plugin_app.cpp b/kapptemplate/kpartplugin/plugin_app.cpp
index 98a44cad..29388b46 100644
--- a/kapptemplate/kpartplugin/plugin_app.cpp
+++ b/kapptemplate/kpartplugin/plugin_app.cpp
@@ -30,10 +30,10 @@ Plugin${APP_NAME}::~Plugin${APP_NAME}()
void Plugin${APP_NAME}::slotAction()
{
// This plugin assumes KHTMLPart. If your plugin can handle more
// than this or a different Part than this, simply delete or
// change the following block.
- if ( !parent()->inherits("KHTMLPart") )
+ if ( !parent()->inherits("TDEHTMLPart") )
{
TQString title( i18n( "Cannot Translate Source" ) );
TQString text( i18n( "You cannot translate anything except web pages "
@@ -45,7 +45,7 @@ void Plugin${APP_NAME}::slotAction()
// Get a handle on our parent so we may get the necessary data for
// processing
- KHTMLPart *part = dynamic_cast<KHTMLPart *>(parent());
+ TDEHTMLPart *part = dynamic_cast<TDEHTMLPart *>(parent());
// This plugin only uses the URL. You may use whatever data you
// need.
@@ -30,10 +30,10 @@ Plugin${APP_NAME}::~Plugin${APP_NAME}()
void Plugin${APP_NAME}::slotAction()
{
- // This plugin assumes KHTMLPart. If your plugin can handle more
+ // This plugin assumes TDEHTMLPart. If your plugin can handle more
// than this or a different Part than this, simply delete or
// change the following block.